RpcFileReference class

Constructors

RpcFileReference.fromJson(Map<String, dynamic> json)
factory

Properties

expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isExpired bool
no setter
localPath String?
final
mediaType String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String
final
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited