SidecarClient class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(String method, {Map<String, Object?> params = const {}, Duration timeout = const Duration(seconds: 5), RpcCancellationToken? cancellationToken})
→ Future<RpcReply>
-
override
-
close()
→ Future<void>
-
override
-
download(RpcFileReference file, {Duration timeout = const Duration(minutes: 15), RpcCancellationToken? cancellationToken, int maxAttempts = 3})
→ Stream<List<int>>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
stream(String method, {Map<String, Object?> params = const {}, Duration timeout = const Duration(minutes: 5), RpcCancellationToken? cancellationToken})
→ Stream<RpcStreamEvent<RpcReply>>
-
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
upload(RpcFileUpload file, {Duration timeout = const Duration(minutes: 15), RpcCancellationToken? cancellationToken, int maxAttempts = 3})
→ Future<RpcFileReference>
-
override