SidecarProcess class abstract interface

Properties

exitCode Future<int>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr Stream<List<int>>
no setter
stdin IOSink
no setter
stdout Stream<List<int>>
no setter

Methods

kill([ProcessSignal signal = ProcessSignal.sigterm]) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited