SidecarRestartPolicy class

Constructors

SidecarRestartPolicy({int maxAttempts = 3, Duration initialDelay = const Duration(milliseconds: 250), Duration maxDelay = const Duration(seconds: 2), double backoffFactor = 2, Duration healthCheckTimeout = const Duration(seconds: 2)})
const
SidecarRestartPolicy.disabled()
const

Properties

backoffFactor double
final
hashCode int
The hash code for this object.
no setterinherited
healthCheckTimeout Duration
final
initialDelay Duration
final
isEnabled bool
no setter
maxAttempts int
final
maxDelay Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delayForAttempt(int attempt) Duration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited